summaryrefslogtreecommitdiff
path: root/src/core/common/Rtti.hpp
diff options
context:
space:
mode:
authorAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-05 20:51:14 +0100
committerAndreas Stöckel <astoecke@techfak.uni-bielefeld.de>2015-01-05 20:51:14 +0100
commit0778a9446dc3475b887d20515165a4dc63ed0cd0 (patch)
treebbd6dc700feb72c5f5f35a204bed083080afa35a /src/core/common/Rtti.hpp
parent15dd9d1aa1e0cfe8b31364fb42985ee8d5c5fc9d (diff)
Replaced the term "aggregation" with "composition"
Diffstat (limited to 'src/core/common/Rtti.hpp')
-rw-r--r--src/core/common/Rtti.hpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/core/common/Rtti.hpp b/src/core/common/Rtti.hpp
index ab937f5..237c60f 100644
--- a/src/core/common/Rtti.hpp
+++ b/src/core/common/Rtti.hpp
@@ -114,9 +114,9 @@ public:
class RttiBase {
private:
/**
* Set to true if once the parents and the aggregated types list have been
* completed (by including the parents of the original parent elements and
* the aggregated types of the original aggregated types).
*/
mutable bool initialized;
@@ -126,14 +126,14 @@ private:
mutable std::unordered_set<const RttiBase *> parents;
/**
* Set containing references to all types this type is aggregated of,
* including all aggregated types of the original aggregated types.
*/
- mutable std::unordered_set<const RttiBase *> aggregatedTypes;
+ mutable std::unordered_set<const RttiBase *> compositeTypes;
/**
* Adds the parent types of the parents and the aggregated types of the
* aggregated types to the internal sets.
*/
void initialize() const;
@@ -162,11 +162,11 @@ public:
RttiBase(std::string name, const std::type_info &native,
std::unordered_set<const RttiBase *> parents =
std::unordered_set<const RttiBase *>{},
- std::unordered_set<const RttiBase *> aggregatedTypes =
+ std::unordered_set<const RttiBase *> compositeTypes =
std::unordered_set<const RttiBase *>{})
: initialized(false),
parents(std::move(parents)),
- aggregatedTypes(aggregatedTypes),
+ compositeTypes(compositeTypes),
name(std::move(name))
{
RttiStore::store(native, this);
@@ -187,9 +187,9 @@ public:
* resolving objects of a certain type by name in an object graph.
*
* @param other is the other type for which should be checked whether this
* type is directly or indirectly aggregated of it.
*/
- bool aggregatedOf(const RttiBase &other) const;
+ bool composedOf(const RttiBase &other) const;
};
/**
@@ -212,10 +212,10 @@ public:
*/
Rtti(std::string name, const std::unordered_set<const RttiBase *> &parents =
std::unordered_set<const RttiBase *>{},
- std::unordered_set<const RttiBase *> aggregatedTypes =
+ std::unordered_set<const RttiBase *> compositeTypes =
std::unordered_set<const RttiBase *>{})
: RttiBase(name, typeid(T), std::move(parents),
- std::move(aggregatedTypes))
+ std::move(compositeTypes))
{
}
};
@@ -114,9 +114,9 @@ public:
private:
/**
- * Set to true if once the parents and the aggregated types list have been
+ * Set to true if once the parents and the composite types list have been
* completed (by including the parents of the original parent elements and
@@ -114,9 +114,9 @@ public:
* completed (by including the parents of the original parent elements and
- * the aggregated types of the original aggregated types).
+ * the composite types of the original composite types).
*/
mutable bool initialized;
@@ -126,14 +126,14 @@ private:
mutable std::unordered_set<const RttiBase *> parents;
/**
- * Set containing references to all types this type is aggregated of,
- * including all aggregated types of the original aggregated types.
+ * Set containing references to all types this type is a composition of,
+ * including all composite types of the original composite types.
*/
@@ -126,14 +126,14 @@ private:
/**
- * Adds the parent types of the parents and the aggregated types of the
- * aggregated types to the internal sets.
+ * Adds the parent types of the original parents and the composite types of
+ * the original composite types to the internal sets for faster lookup.
*/
void initialize() const;
@@ -187,9 +187,9 @@ public:
*
* @param other is the other type for which should be checked whether this
- * type is directly or indirectly aggregated of it.
+ * type is directly or indirectly composed of it.
*/